<?php

namespace Drupal\graphql_address\Plugin\GraphQL\Fields\Address;

use Drupal\graphql\GraphQL\Execution\ResolveContext;
use Drupal\graphql\Plugin\GraphQL\Fields\FieldPluginBase;
use GraphQL\Type\Definition\ResolveInfo;

/**
 * The localities dependant on a administrative area.
 *
 * @GraphQLField(
 *   secure = true,
 *   id = "address_localities",
 *   name = "localities",
 *   parents = {"AddressAdministrativeArea"},
 *   type = "[AddressLocality]",
 * )
 */
class AddressLocalities extends FieldPluginBase {

  /**
   * {@inheritdoc}
   */
  public function resolveValues($value, array $args, ResolveContext $context, ResolveInfo $info) {

    // Obtain the localities subdivision from the parents
    // (country and admin area).
    $localities = \Drupal::service('address.subdivision_repository')->getList($value['parents']);
    $parents = $value['parents'];

    /**
     * @var \CommerceGuys\Addressing\Subdivision\Subdivision $administrative_area
     */
    foreach ($localities as $locality_code => $locality) {
      $parents[] = $locality_code;
      // Return a new AddressLocality GraphQL type with the locality name and
      // parents.
      yield [
        'result_type' => 'AddressLocality',
        'name' => $locality,
        'parents' => $parents,
      ];
    }
  }

}
